/**
 * @license
 * Copyright 2019 Google LLC
 * SPDX-License-Identifier: BSD-3-Clause
 */
import { Directive, PartInfo } from './directive.js';
import { AttributePart, Part } from './lit-html.js';
export type { Template } from './lit-html.js';
/**
 * END USERS SHOULD NOT RELY ON THIS OBJECT.
 *
 * We currently do not make a mangled rollup build of the lit-ssr code. In order
 * to keep a number of (otherwise private) top-level exports mangled in the
 * client side code, we export a _Σ object containing those members (or
 * helper methods for accessing private fields of those members), and then
 * re-export them for use in lit-ssr. This keeps lit-ssr agnostic to whether the
 * client-side code is being used in `dev` mode or `prod` mode.
 * @private
 */
export declare const _Σ: {
    boundAttributeSuffix: string;
    marker: string;
    markerMatch: string;
    HTML_RESULT: number;
    getTemplateHtml: (strings: TemplateStringsArray, type: 1 | 2) => [string, (string | undefined)[]];
    overrideDirectiveResolve: (directiveClass: new (part: PartInfo) => Directive & {
        render(): unknown;
    }, resolveOverrideFn: (directive: Directive, values: unknown[]) => unknown) => {
        new (part: PartInfo): {
            _$resolve(this: Directive, _part: Part, values: unknown[]): unknown;
            __part: Part;
            __attributeIndex: number | undefined;
            __directive?: Directive | undefined;
            _$parent: import("./lit-html.js").Disconnectable;
            _$disconnetableChildren?: Set<import("./lit-html.js").Disconnectable> | undefined;
            _$setDirectiveConnected?(isConnected: boolean): void;
            _$initialize(part: Part, parent: import("./lit-html.js").Disconnectable, attributeIndex: number | undefined): void;
            render: ((...props: unknown[]) => unknown) & (() => unknown);
            update(_part: Part, props: unknown[]): unknown;
        };
    };
    getAttributePartCommittedValue: (part: AttributePart, value: unknown, index: number | undefined) => unknown;
    resolveDirective: (part: {
        readonly type: 2;
        readonly options: import("./lit-html.js").RenderOptions | undefined;
        _$committedValue: unknown;
        __directive?: Directive | undefined;
        _$startNode: ChildNode;
        _$endNode: ChildNode | null;
        _$parent: import("./lit-html.js").Disconnectable | undefined;
        _$disconnetableChildren?: Set<import("./lit-html.js").Disconnectable> | undefined;
        _$setChildPartConnected?: ((isConnected: boolean, removeFromParent?: boolean | undefined, from?: number | undefined) => void) | undefined;
        _$reparentDisconnectables?: ((parent: import("./lit-html.js").Disconnectable) => void) | undefined;
        setConnected: (isConnected: boolean) => void;
        readonly parentNode: Node;
        readonly startNode: Node | null;
        readonly endNode: Node | null;
        _$setValue: (value: unknown, directiveParent?: import("./lit-html.js").DirectiveParent) => void;
        _$getTemplate: (result: import("./lit-html.js").TemplateResult<1 | 2>) => import("./lit-html.js").Template;
        _$clear: (start?: ChildNode | null, from?: number | undefined) => void;
    } | {
        readonly type: 1 | 3 | 4 | 5;
        readonly element: HTMLElement;
        readonly name: string;
        readonly options: import("./lit-html.js").RenderOptions | undefined;
        readonly strings?: readonly string[] | undefined;
        _$committedValue: unknown;
        __directives?: (Directive | undefined)[] | undefined;
        _$parent: import("./lit-html.js").Disconnectable | undefined;
        _$disconnetableChildren?: Set<import("./lit-html.js").Disconnectable> | undefined;
        _setDirectiveConnected?: ((directive: Directive | undefined, isConnected: boolean, removeFromParent?: boolean | undefined) => void) | undefined;
        readonly tagName: string;
        _$setValue: (value: unknown, directiveParent?: import("./lit-html.js").DirectiveParent, valueIndex?: number | undefined, noCommit?: boolean | undefined) => void;
        _commitValue: (value: unknown) => void;
    } | {
        readonly type: 6;
        __directive?: Directive | undefined;
        _$committedValue: undefined;
        _$parent: import("./lit-html.js").Disconnectable | undefined;
        _$disconnetableChildren?: Set<import("./lit-html.js").Disconnectable> | undefined;
        _setDirectiveConnected?: ((directive: Directive | undefined, isConnected: boolean, removeFromParent?: boolean | undefined) => void) | undefined;
        options: import("./lit-html.js").RenderOptions | undefined;
        element: Element;
        _$setValue: (value: unknown) => void;
    }, value: unknown, parent?: import("./lit-html.js").DirectiveParent, attributeIndex?: number | undefined) => unknown;
    AttributePart: new (element: HTMLElement, name: string, strings: readonly string[], parent: import("./lit-html.js").Disconnectable | undefined, options: import("./lit-html.js").RenderOptions | undefined) => {
        readonly type: 1 | 3 | 4 | 5;
        readonly element: HTMLElement;
        readonly name: string;
        readonly options: import("./lit-html.js").RenderOptions | undefined;
        readonly strings?: readonly string[] | undefined;
        _$committedValue: unknown;
        __directives?: (Directive | undefined)[] | undefined;
        _$parent: import("./lit-html.js").Disconnectable | undefined;
        _$disconnetableChildren?: Set<import("./lit-html.js").Disconnectable> | undefined;
        _setDirectiveConnected?: ((directive: Directive | undefined, isConnected: boolean, removeFromParent?: boolean | undefined) => void) | undefined;
        readonly tagName: string;
        _$setValue: (value: unknown, directiveParent?: import("./lit-html.js").DirectiveParent, valueIndex?: number | undefined, noCommit?: boolean | undefined) => void;
        _commitValue: (value: unknown) => void;
    };
    PropertyPart: new (element: HTMLElement, name: string, strings: readonly string[], parent: import("./lit-html.js").Disconnectable | undefined, options: import("./lit-html.js").RenderOptions | undefined) => {
        readonly type: 1 | 3 | 4 | 5;
        readonly element: HTMLElement;
        readonly name: string;
        readonly options: import("./lit-html.js").RenderOptions | undefined;
        readonly strings?: readonly string[] | undefined;
        _$committedValue: unknown;
        __directives?: (Directive | undefined)[] | undefined;
        _$parent: import("./lit-html.js").Disconnectable | undefined;
        _$disconnetableChildren?: Set<import("./lit-html.js").Disconnectable> | undefined;
        _setDirectiveConnected?: ((directive: Directive | undefined, isConnected: boolean, removeFromParent?: boolean | undefined) => void) | undefined;
        readonly tagName: string;
        _$setValue: (value: unknown, directiveParent?: import("./lit-html.js").DirectiveParent, valueIndex?: number | undefined, noCommit?: boolean | undefined) => void;
        _commitValue: (value: unknown) => void;
    };
    BooleanAttributePart: new (element: HTMLElement, name: string, strings: readonly string[], parent: import("./lit-html.js").Disconnectable | undefined, options: import("./lit-html.js").RenderOptions | undefined) => {
        readonly type: 1 | 3 | 4 | 5;
        readonly element: HTMLElement;
        readonly name: string;
        readonly options: import("./lit-html.js").RenderOptions | undefined;
        readonly strings?: readonly string[] | undefined;
        _$committedValue: unknown;
        __directives?: (Directive | undefined)[] | undefined;
        _$parent: import("./lit-html.js").Disconnectable | undefined;
        _$disconnetableChildren?: Set<import("./lit-html.js").Disconnectable> | undefined;
        _setDirectiveConnected?: ((directive: Directive | undefined, isConnected: boolean, removeFromParent?: boolean | undefined) => void) | undefined;
        readonly tagName: string;
        _$setValue: (value: unknown, directiveParent?: import("./lit-html.js").DirectiveParent, valueIndex?: number | undefined, noCommit?: boolean | undefined) => void;
        _commitValue: (value: unknown) => void;
    };
    EventPart: new (element: HTMLElement, name: string, strings: readonly string[], parent: import("./lit-html.js").Disconnectable | undefined, options: import("./lit-html.js").RenderOptions | undefined) => {
        readonly type: 1 | 3 | 4 | 5;
        readonly element: HTMLElement;
        readonly name: string;
        readonly options: import("./lit-html.js").RenderOptions | undefined;
        readonly strings?: readonly string[] | undefined;
        _$committedValue: unknown;
        __directives?: (Directive | undefined)[] | undefined;
        _$parent: import("./lit-html.js").Disconnectable | undefined;
        _$disconnetableChildren?: Set<import("./lit-html.js").Disconnectable> | undefined;
        _setDirectiveConnected?: ((directive: Directive | undefined, isConnected: boolean, removeFromParent?: boolean | undefined) => void) | undefined;
        readonly tagName: string;
        _$setValue: (value: unknown, directiveParent?: import("./lit-html.js").DirectiveParent, valueIndex?: number | undefined, noCommit?: boolean | undefined) => void;
        _commitValue: (value: unknown) => void;
    };
    ElementPart: new (element: HTMLElement, parent: import("./lit-html.js").Disconnectable | undefined, options: import("./lit-html.js").RenderOptions | undefined) => {
        readonly type: 6;
        __directive?: Directive | undefined;
        _$committedValue: undefined;
        _$parent: import("./lit-html.js").Disconnectable | undefined;
        _$disconnetableChildren?: Set<import("./lit-html.js").Disconnectable> | undefined;
        _setDirectiveConnected?: ((directive: Directive | undefined, isConnected: boolean, removeFromParent?: boolean | undefined) => void) | undefined;
        options: import("./lit-html.js").RenderOptions | undefined;
        element: Element;
        _$setValue: (value: unknown) => void;
    };
};
//# sourceMappingURL=private-ssr-support.d.ts.map